@@ -805,7 +805,7 @@ Text::ANSI::Util - Routines for text containing ANSI escape codes
 
 =head1 VERSION
 
-This document describes version 0.16 of Text::ANSI::Util (from Perl distribution Perinci-CmdLine-Any-Lumped version 0.08), released on 2015-01-03.
+This document describes version 0.16 of Text::ANSI::Util (from Perl distribution Perinci-CmdLine-Any-Lumped version 0.09), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -826,10 +826,10 @@ This document describes version 0.16 of Text::ANSI::Util (from Perl distribution
  # calculate visual width of text if printed on terminal (can handle Unicode
  # wide characters and exclude the ANSI escape codes)
  say ta_mbswidth("\e[31mred");  # => 3
- say ta_mbswidth("\e[31mÃÂÃÂ§ÃÂÃÂºÃÂÃÂ¢ÃÂÃÂ¨ÃÂÃÂÃÂÃÂ²"); # => 4
+ say ta_mbswidth("\e[31mÃÂÃÂÃÂÃÂ§ÃÂÃÂÃÂÃÂºÃÂÃÂÃÂÃÂ¢ÃÂÃÂÃÂÃÂ¨ÃÂÃÂÃÂÃÂÃÂÃÂÃÂÃÂ²"); # => 4
 
  # ditto, but also return the number of lines
- say ta_mbswidth_height("\e[31mred\nÃÂÃÂ§ÃÂÃÂºÃÂÃÂ¢ÃÂÃÂ¨ÃÂÃÂÃÂÃÂ²"); # => [4, 2]
+ say ta_mbswidth_height("\e[31mred\nÃÂÃÂÃÂÃÂ§ÃÂÃÂÃÂÃÂºÃÂÃÂÃÂÃÂ¢ÃÂÃÂÃÂÃÂ¨ÃÂÃÂÃÂÃÂÃÂÃÂÃÂÃÂ²"); # => [4, 2]
 
  # strip ANSI escape codes
  say ta_strip("\e[31mred"); # => "red"
@@ -927,7 +927,7 @@ text first against C<< /\r?\n/ >>.
 =head2 ta_mbswidth_height($text) => [INT, INT]
 
 Like C<ta_mbswidth()>, but also gives height (number of lines). For example, C<<
-ta_mbswidth_height("ÃÂÃÂ¨ÃÂÃÂ¥ÃÂÃÂ¿ÃÂÃÂ§ÃÂÃÂÃÂÃÂªÃÂÃÂ¥ÃÂÃÂÃÂÃÂ\nb\n") >> gives [6, 3].
+ta_mbswidth_height("ÃÂÃÂÃÂÃÂ¨ÃÂÃÂÃÂÃÂ¥ÃÂÃÂÃÂÃÂ¿ÃÂÃÂÃÂÃÂ§ÃÂÃÂÃÂÃÂÃÂÃÂÃÂÃÂªÃÂÃÂÃÂÃÂ¥ÃÂÃÂÃÂÃÂÃÂÃÂÃÂÃÂ\nb\n") >> gives [6, 3].
 
 =head2 ta_strip($text) => STR
 
